@@ -3,49 +3,74 @@
 #' @export
 #' @template all
 #' @param ids More than one document id, see examples.
-#' @param type_id List of vectors of length 2, each with an element for type and id.
-#' @param index_type_id List of vectors of length 3, each with an element for index,
-#' type, and id.
+#' @param type_id List of vectors of length 2, each with an element for 
+#' type and id.
+#' @param index_type_id List of vectors of length 3, each with an element for 
+#' index, type, and id.
 #' @param source (logical) If \code{TRUE}, return source.
 #' @param fields Fields to return from the response object.
 #'
-#' @references 
+#' @references
 #' \url{https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-multi-get.html}
-#' @details 
+#' 
+#' @details
 #'
 #' You can pass in one of three combinations of parameters:
 #' \itemize{
-#'  \item Pass in something for \code{index}, \code{type}, and \code{id}. This is the simplest,
-#'  allowing retrieval from the same index, same type, and many ids.
-#'  \item Pass in only \code{index} and \code{type_id} - this allows you to get multiple
-#'  documents from the same index, but from different types.
-#'  \item Pass in only \code{index_type_id} - this is so that you can get multiple documents
-#'  from different indexes and different types.
+#'  \item Pass in something for \code{index}, \code{type}, and \code{id}. 
+#'  This is the simplest, allowing retrieval from the same index, same type, 
+#'  and many ids.
+#'  \item Pass in only \code{index} and \code{type_id} - this allows you to 
+#'  get multiple documents from the same index, but from different types.
+#'  \item Pass in only \code{index_type_id} - this is so that you can get 
+#'  multiple documents from different indexes and different types.
 #' }
 #' @examples \dontrun{
+#' connect()
+#' 
+#' if (!index_exists('plos')) {
+#'   plosdat <- system.file("examples", "plos_data.json", package = "elastic")
+#'   invisible(docs_bulk(plosdat))
+#' }
+#' 
 #' # Same index and type
-#' docs_mget(index="shakespeare", type="line", ids=c(9,10))
-#' tmp <- docs_mget(index="mran", type="metadata", ids=c('plyr','ggplot2'), raw=TRUE)
+#' docs_mget(index="plos", type="article", ids=c(9,10))
+#' 
+#' tmp <- docs_mget(index="plos", type="article", ids=c(9, 10), 
+#'   raw=TRUE)
 #' es_parse(tmp)
-#' docs_mget(index="mran", type="metadata", ids=c('plyr','ggplot2'), fields='description')
-#' docs_mget(index="mran", type="metadata", ids=c('plyr','ggplot2'), source=TRUE)
-#'
+#' docs_mget(index="plos", type="article", ids=c(9, 10), 
+#'   source='title')
+#' docs_mget(index="plos", type="article", ids=c(14, 19), 
+#'   source=TRUE)
+#' 
+#' # curl options
 #' library("httr")
-#' docs_mget(index="twitter", type="tweet", ids=1:2, callopts=verbose())
+#' docs_mget(index="plos", type="article", ids=1:2, callopts=verbose())
 #'
 #' # Same index, but different types
+#' if (!index_exists('shakespeare')) {
+#'   shakedat <- system.file("examples", "shakespeare_data.json", package = "elastic")
+#'   invisible(docs_bulk(shakedat))
+#' }
+#' 
 #' docs_mget(index="shakespeare", type_id=list(c("scene",1), c("line",20)))
-#' docs_mget(index="shakespeare", type_id=list(c("scene",1), c("line",20)), fields='play_name')
+#' docs_mget(index="shakespeare", type_id=list(c("scene",1), c("line",20)), 
+#'   source='play_name')
 #'
-#' # Different indices and different types
-#' # pass in separately
-#' docs_mget(index_type_id=list(c("shakespeare","line",1), c("plos","article",1)))
+#' # Different indices and different types pass in separately
+#' docs_mget(index_type_id = list(
+#'   c("shakespeare", "line", 20), 
+#'   c("plos", "article", 1)
+#'  )
+#' )
 #' }
 
-docs_mget <- function(index=NULL, type=NULL, ids=NULL, type_id=NULL, index_type_id=NULL,
-  source=NULL, fields=NULL, raw=FALSE, callopts=list(), verbose=TRUE, ...) {
+docs_mget <- function(index=NULL, type=NULL, ids=NULL, type_id=NULL, 
+  index_type_id=NULL, source=NULL, fields=NULL, raw=FALSE, callopts=list(), 
+  verbose=TRUE, ...) {
 
-  checkconn()
+  #checkconn()
   check_params(index, type, ids, type_id, index_type_id)
   base <- make_url(es_get_auth())
 
@@ -53,12 +78,12 @@ docs_mget <- function(index=NULL, type=NULL, ids=NULL, type_id=NULL, index_type_
     if (length(ids) < 2) stop("If ids parameter is used, more than 1 id must be passed", call. = FALSE)
   }
 
-  fields <- if (is.null(fields)) {
-    fields
-  } else {
-    paste(fields, collapse = ",")
-  }
+  fields <- cw(fields)
+  if (inherits(source, "logical")) source <- tolower(source)
+  source <- cw(source)
   args <- ec(list(...))
+  if (!is.null(fields)) args$fields <- fields
+  if (!is.null(source)) args$`_source` <- source
   if (length(args) == 0) args <- NULL
 
   # One index, one type, one to many ids
@@ -77,7 +102,7 @@ docs_mget <- function(index=NULL, type=NULL, ids=NULL, type_id=NULL, index_type_
     docs <- lapply(type_id, function(x){
       list(`_type` = esc(x[[1]]), `_id` = x[[2]])
     })
-    docs <- lapply(docs, function(y) modifyList(y, list(`_source` = source, fields = fields)))
+    #docs <- lapply(docs, function(y) modifyList(y, list(`_source` = source, fields = fields)))
     tt <- jsonlite::toJSON(list("docs" = docs))
     url <- paste(base, esc(index), '_mget', sep = "/")
     out <- POST(url, c(es_env$headers, mc(make_up(), callopts)), body = tt, encode = 'json', query = args)
@@ -88,7 +113,8 @@ docs_mget <- function(index=NULL, type=NULL, ids=NULL, type_id=NULL, index_type_
     # check for 3 elements in each element
     stopifnot(all(sapply(index_type_id, function(x) length(x) == 3)))
     docs <- lapply(index_type_id, function(x){
-      modifyList(list(`_index` = esc(x[[1]]), `_type` = esc(x[[2]]), `_id` = x[[3]]), list(fields = fields))
+      #modifyList(list(`_index` = esc(x[[1]]), `_type` = esc(x[[2]]), `_id` = esc(x[[3]])), list(fields = fields))
+      list(`_index` = esc(x[[1]]), `_type` = esc(x[[2]]), `_id` = x[[3]])
     })
     tt <- jsonlite::toJSON(list("docs" = docs))
     url <- paste(base, '_mget', sep = "/")
