@@ -30,7 +30,6 @@ test_that("docs_create fails as expected", {
 
   expect_error(docs_get("bbbbbbb"), "argument \"type\" is missing, with no default")
   expect_error(docs_get("bbbbbbb", "stuff"), "argument \"id\" is missing, with no default")
-  expect_error(docs_get("bbbbbbb", "stuff", 1, source = "adf"), "argument is not interpretable as logical")
 })
 
 ## create indices first
@@ -81,7 +80,66 @@ test_that("docs_delete works", {
   expect_error(docs_delete(index = ind3, type = "holla", id = 3), "Not Found")
 })
 
+
+## create indices first
+ind4 <- "stuff_ids"
+invisible(tryCatch(index_delete(index = ind4, verbose = FALSE), error = function(e) e))
+invisible(index_create(index = ind4, verbose = FALSE))
+
+ind5 <- "stuff_zzz"
+invisible(tryCatch(index_delete(index = ind5, verbose = FALSE), error = function(e) e))
+invisible(index_create(index = ind5, verbose = FALSE))
+
+test_that("document ids with spaces work", {
+  
+  # create
+  f <- docs_create(index = ind4, type = ind4, id = "hello world", body = list(a = "asdfasdf"))
+  invisible(docs_create(index = ind4, type = ind4, id = "foo bar", body = list(a = "asdfadfadfasdfasdfsdf")))
+  invisible(docs_create(index = ind4, type = "dattype", id = "what the", body = list(a = "cars")))
+  expect_is(f, "list")
+  expect_equal(f$`_id`, "hello world")
+  
+  # get
+  g <- docs_get(index = ind4, type = ind4, id = "hello world", verbose = FALSE)
+  expect_is(g, "list")
+  expect_true(g$found)
+  
+  # mget - ids param
+  h <- docs_mget(index = ind4, type = ind4, ids = c("hello world", "foo bar"), verbose = FALSE)
+  expect_is(h, "list")
+  expect_equal(length(h$docs), 2)
+  expect_true(all(vapply(h$docs, "[[", logical(1), "found")))
+  
+  # mget - type_id param
+  hh <- docs_mget(index = ind4, type_id = list(c(ind4, "hello world"), c("dattype", "what the")), verbose = FALSE)
+  expect_is(hh, "list")
+  expect_equal(length(hh$docs), 2)
+  expect_true(all(vapply(hh$docs, "[[", logical(1), "found")))
+  
+  # mget - index_type_id param
+  invisible(docs_create(index = ind5, type = ind5, id = "hello mars", body = list(radius = 1000000L)))
+  
+  hhh <- docs_mget(index_type_id = list(
+    c(ind4, ind4, "hello world"), 
+    c(ind5, ind5, "hello mars")
+  ), verbose = FALSE)
+  expect_is(hhh, "list")
+  expect_equal(length(hhh$docs), 2)
+  expect_true(all(vapply(hhh$docs, "[[", logical(1), "found")))
+  
+  # update
+  i <- docs_update(index = ind4, type = ind4, id = "hello world", body = list(doc = list(a = "an update")))
+  expect_is(i, "list")
+  
+  # delete
+  j <- docs_delete(index = ind4, type = ind4, id = "hello world")
+  expect_is(j, "list")
+  expect_true(j$found)
+})
+
 ## cleanup -----------------------------------
 invisible(index_delete(ind, verbose = FALSE))
 invisible(index_delete(ind2, verbose = FALSE))
 invisible(index_delete(ind3, verbose = FALSE))
+invisible(index_delete(ind4, verbose = FALSE))
+invisible(index_delete(ind5, verbose = FALSE))
